@@ -29,10 +29,15 @@ def VacancyAnalysis():
     cs_out_dir = Path("inputs")
     cs_generator = CrystalStructureGenerator(configuracion, cs_out_dir)
     dump_path = cs_generator.generate()
-    print(f"Estructura relajada generada en: {dump_path}")
+    #print(f"Estructura relajada generada en: {dump_path}")
     if configuracion['training']:
-        processor = TrainingProcessor()
-        processor.run()
+        gen = AtomicGraphGenerator()
+        gen.run()
+
+
+
+
+        
     processor = ClusterProcessor(defect_file)
     processor.run()
     separator = KeyFilesSeparator(configuracion, os.path.join("outputs/json", "clusters.json"))
